==> haskell-hint-0.9.0.3-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hint
version:              0.9.0.3
visibility:           public
id:                   hint-0.9.0.3-37mvqi8v1p7PwEJh6lsm1
key:                  hint-0.9.0.3-37mvqi8v1p7PwEJh6lsm1
license:              BSD-3-Clause
maintainer:           mvdan@mvdan.cc
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             Runtime Haskell interpreter (GHC API wrapper)
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  5e8a5b36560ce8db87b1045b74e90065
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-8.10.3/site-local/hint-0.9.0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hint-0.9.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hint-0.9.0.3
hs-libraries:         HShint-0.9.0.3-37mvqi8v1p7PwEJh6lsm1
depends:
    base-4.14.1.0 directory-1.3.6.0 exceptions-0.10.4 filepath-1.4.2.1
    ghc-8.10.3 ghc-boot-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    random-1.2.0-2oMeoq1l81e2o54ELOj6Jv
    temporary-1.3-1IMBkjh3EgS7aRRZacwYZg transformers-0.5.6.2
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hint-0.9.0.3-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hint
version:              0.9.0.3
visibility:           public
id:                   hint-0.9.0.3-6BpG1xioPVl2G5OVALIh7m
key:                  hint-0.9.0.3-6BpG1xioPVl2G5OVALIh7m
license:              BSD-3-Clause
maintainer:           mvdan@mvdan.cc
author:               The Hint Authors
homepage:             https://github.com/haskell-hint/hint
synopsis:             Runtime Haskell interpreter (GHC API wrapper)
description:
    This library defines an Interpreter monad. It allows to load Haskell
    modules, browse them, type-check and evaluate strings with Haskell
    expressions and even coerce them into values. The library is thread-safe
    and type-safe (even the coercion of expressions to values).
    It is, essentially, a huge subset of the GHC API wrapped in a simpler
    API.

category:             Language, Compilers/Interpreters
abi:                  be04081568969ebce3dbd16f063eab33
exposed:              True
exposed-modules:
    Hint.Internal Language.Haskell.Interpreter
    Language.Haskell.Interpreter.Extension
    Language.Haskell.Interpreter.Unsafe

hidden-modules:
    Hint.GHC Hint.Base Hint.InterpreterT Hint.CompatPlatform
    Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
    Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Util
    Hint.Annotations Control.Monad.Ghc

import-dirs:          /usr/lib/ghc-8.10.3/site-local/hint-0.9.0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hint-0.9.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hint-0.9.0.3
hs-libraries:         HShint-0.9.0.3-6BpG1xioPVl2G5OVALIh7m
depends:
    base-4.14.1.0 directory-1.3.6.0 exceptions-0.10.4 filepath-1.4.2.1
    ghc-8.10.3 ghc-boot-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    random-1.2.0-H2LhGpStkJj2sCkwVKLQmg
    temporary-1.3-HSi6zDu4rXQPDXDBHna7q transformers-0.5.6.2
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hint/html/hint.haddock
haddock-html:         /usr/share/doc/haskell-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
